//-----------------------------------------------------------------------------
//! \addtogroup AT91
//! @{
//
//  All rights reserved ADENEO SAS 2005
//
//! \file		at91_sddrc.h
//!
//! \if subversion
///   @URL: $URL: http://centaure/svn/interne-ce_bsp_atmel/TAGS/TAGS60/RC/SAM9263_v130_rc7/PLATFORM/COMMON/SRC/SOC/ATMEL/COMMON/INC/CONTROLLER/at91_sddrc.h $
//!   @author $Author: pgal $
//!   @version $Revision: 1139 $
//!   @date $Date: 2007-07-27 11:47:39 +0200 (ven., 27 juil. 2007) $
//! \endif
// 
//-----------------------------------------------------------------------------
#ifndef SDRAM_H
#define SDRAM_H

#include "at91_typedef.h"

// *****************************************************************************
//              SOFTWARE API DEFINITION  FOR DDR/SDRAM Controller
// *****************************************************************************
typedef struct _AT91S_SDDRC {
	AT91_REG	 SDDRC_MR; 	// 
	AT91_REG	 SDDRC_RTR; 	// 
	AT91_REG	 SDDRC_CR; 	// 
	AT91_REG	 SDDRC_T0PR; 	// 
	AT91_REG	 SDDRC_T1PR; 	// 
	AT91_REG	 SDDRC_HS; 	// 
	AT91_REG	 SDDRC_LPR; 	// 
	AT91_REG	 SDDRC_MDR; 	// 
	AT91_REG	 Reserved0[55]; 	// 
	AT91_REG	 SDDRC_VERSION; 	// 
} AT91S_SDDRC, *AT91PS_SDDRC;

// -------- SDDRC_MR : (SDDRC Offset: 0x0)  -------- 
#define AT91C_MODE            ((unsigned int) 0xF <<  0) // (SDDRC) 
#define 	AT91C_MODE_NORMAL_CMD           ((unsigned int) 0x0) // (SDDRC) Normal Mode
#define 	AT91C_MODE_NOP_CMD              ((unsigned int) 0x1) // (SDDRC) Issue a NOP Command at every access
#define 	AT91C_MODE_PRCGALL_CMD          ((unsigned int) 0x2) // (SDDRC) Issue a All Banks Precharge Command at every access
#define 	AT91C_MODE_LMR_CMD              ((unsigned int) 0x3) // (SDDRC) Issue a Load Mode Register at every access
#define 	AT91C_MODE_RFSH_CMD             ((unsigned int) 0x4) // (SDDRC) Issue a Refresh
#define 	AT91C_MODE_EXT_LMR_CMD          ((unsigned int) 0x5) // (SDDRC) Issue an Extended Load Mode Register
#define 	AT91C_MODE_DEEP_CMD             ((unsigned int) 0x6) // (SDDRC) Enter Deep Power Mode
// -------- SDDRC_RTR : (SDDRC Offset: 0x4)  -------- 
#define AT91C_COUNT           ((unsigned int) 0xFFF <<  0) // (SDDRC) 
// -------- SDDRC_CR : (SDDRC Offset: 0x8)  -------- 
#define AT91C_NC              ((unsigned int) 0x3 <<  0) // (SDDRC) 
#define 	AT91C_NC_DDR9_SDR8            ((unsigned int) 0x0) // (SDDRC) DDR 9 Bits | SDR 8 Bits
#define 	AT91C_NC_DDR10_SDR9           ((unsigned int) 0x1) // (SDDRC) DDR 10 Bits | SDR 9 Bits
#define 	AT91C_NC_DDR11_SDR10          ((unsigned int) 0x2) // (SDDRC) DDR 11 Bits | SDR 10 Bits
#define 	AT91C_NC_DDR12_SDR11          ((unsigned int) 0x3) // (SDDRC) DDR 12 Bits | SDR 11 Bits
#define AT91C_NR              ((unsigned int) 0x3 <<  2) // (SDDRC) 
#define 	AT91C_NR_11                   ((unsigned int) 0x0 <<  2) // (SDDRC) 11 Bits
#define 	AT91C_NR_12                   ((unsigned int) 0x1 <<  2) // (SDDRC) 12 Bits
#define 	AT91C_NR_13                   ((unsigned int) 0x2 <<  2) // (SDDRC) 13 Bits
#define 	AT91C_NR_14                   ((unsigned int) 0x3 <<  2) // (SDDRC) 14 Bits
#define AT91C_CAS             ((unsigned int) 0x7 <<  4) // (SDDRC) 
#define 	AT91C_CAS_2                    ((unsigned int) 0x2 <<  4) // (SDDRC) 2 cycles
#define 	AT91C_CAS_3                    ((unsigned int) 0x3 <<  4) // (SDDRC) 3 cycles
#define AT91C_DLL             ((unsigned int) 0x1 <<  7) // (SDDRC) 
#define 	AT91C_DLL_RESET_DISABLED       ((unsigned int) 0x0 <<  7) // (SDDRC) Disable DLL reset
#define 	AT91C_DLL_RESET_ENABLED        ((unsigned int) 0x1 <<  7) // (SDDRC) Enable DLL reset
#define AT91C_DIC_DS          ((unsigned int) 0x1 <<  8) // (SDDRC) 
// -------- SDDRC_T0PR : (SDDRC Offset: 0xc)  -------- 
#define AT91C_TRAS            ((unsigned int) 0xF <<  0) // (SDDRC) 
#define 	AT91C_TRAS_0                    ((unsigned int) 0x0) // (SDDRC) Value :  0
#define 	AT91C_TRAS_1                    ((unsigned int) 0x1) // (SDDRC) Value :  1
#define 	AT91C_TRAS_2                    ((unsigned int) 0x2) // (SDDRC) Value :  2
#define 	AT91C_TRAS_3                    ((unsigned int) 0x3) // (SDDRC) Value :  3
#define 	AT91C_TRAS_4                    ((unsigned int) 0x4) // (SDDRC) Value :  4
#define 	AT91C_TRAS_5                    ((unsigned int) 0x5) // (SDDRC) Value :  5
#define 	AT91C_TRAS_6                    ((unsigned int) 0x6) // (SDDRC) Value :  6
#define 	AT91C_TRAS_7                    ((unsigned int) 0x7) // (SDDRC) Value :  7
#define 	AT91C_TRAS_8                    ((unsigned int) 0x8) // (SDDRC) Value :  8
#define 	AT91C_TRAS_9                    ((unsigned int) 0x9) // (SDDRC) Value :  9
#define 	AT91C_TRAS_10                   ((unsigned int) 0xA) // (SDDRC) Value : 10
#define 	AT91C_TRAS_11                   ((unsigned int) 0xB) // (SDDRC) Value : 11
#define 	AT91C_TRAS_12                   ((unsigned int) 0xC) // (SDDRC) Value : 12
#define 	AT91C_TRAS_13                   ((unsigned int) 0xD) // (SDDRC) Value : 13
#define 	AT91C_TRAS_14                   ((unsigned int) 0xE) // (SDDRC) Value : 14
#define 	AT91C_TRAS_15                   ((unsigned int) 0xF) // (SDDRC) Value : 15
#define AT91C_TRCD            ((unsigned int) 0xF <<  4) // (SDDRC) 
#define 	AT91C_TRCD_0                    ((unsigned int) 0x0 <<  4) // (SDDRC) Value :  0
#define 	AT91C_TRCD_1                    ((unsigned int) 0x1 <<  4) // (SDDRC) Value :  1
#define 	AT91C_TRCD_2                    ((unsigned int) 0x2 <<  4) // (SDDRC) Value :  2
#define 	AT91C_TRCD_3                    ((unsigned int) 0x3 <<  4) // (SDDRC) Value :  3
#define 	AT91C_TRCD_4                    ((unsigned int) 0x4 <<  4) // (SDDRC) Value :  4
#define 	AT91C_TRCD_5                    ((unsigned int) 0x5 <<  4) // (SDDRC) Value :  5
#define 	AT91C_TRCD_6                    ((unsigned int) 0x6 <<  4) // (SDDRC) Value :  6
#define 	AT91C_TRCD_7                    ((unsigned int) 0x7 <<  4) // (SDDRC) Value :  7
#define 	AT91C_TRCD_8                    ((unsigned int) 0x8 <<  4) // (SDDRC) Value :  8
#define 	AT91C_TRCD_9                    ((unsigned int) 0x9 <<  4) // (SDDRC) Value :  9
#define 	AT91C_TRCD_10                   ((unsigned int) 0xA <<  4) // (SDDRC) Value : 10
#define 	AT91C_TRCD_11                   ((unsigned int) 0xB <<  4) // (SDDRC) Value : 11
#define 	AT91C_TRCD_12                   ((unsigned int) 0xC <<  4) // (SDDRC) Value : 12
#define 	AT91C_TRCD_13                   ((unsigned int) 0xD <<  4) // (SDDRC) Value : 13
#define 	AT91C_TRCD_14                   ((unsigned int) 0xE <<  4) // (SDDRC) Value : 14
#define 	AT91C_TRCD_15                   ((unsigned int) 0xF <<  4) // (SDDRC) Value : 15
#define AT91C_TWR             ((unsigned int) 0xF <<  8) // (SDDRC) 
#define 	AT91C_TWR_0                    ((unsigned int) 0x0 <<  8) // (SDDRC) Value :  0
#define 	AT91C_TWR_1                    ((unsigned int) 0x1 <<  8) // (SDDRC) Value :  1
#define 	AT91C_TWR_2                    ((unsigned int) 0x2 <<  8) // (SDDRC) Value :  2
#define 	AT91C_TWR_3                    ((unsigned int) 0x3 <<  8) // (SDDRC) Value :  3
#define 	AT91C_TWR_4                    ((unsigned int) 0x4 <<  8) // (SDDRC) Value :  4
#define 	AT91C_TWR_5                    ((unsigned int) 0x5 <<  8) // (SDDRC) Value :  5
#define 	AT91C_TWR_6                    ((unsigned int) 0x6 <<  8) // (SDDRC) Value :  6
#define 	AT91C_TWR_7                    ((unsigned int) 0x7 <<  8) // (SDDRC) Value :  7
#define 	AT91C_TWR_8                    ((unsigned int) 0x8 <<  8) // (SDDRC) Value :  8
#define 	AT91C_TWR_9                    ((unsigned int) 0x9 <<  8) // (SDDRC) Value :  9
#define 	AT91C_TWR_10                   ((unsigned int) 0xA <<  8) // (SDDRC) Value : 10
#define 	AT91C_TWR_11                   ((unsigned int) 0xB <<  8) // (SDDRC) Value : 11
#define 	AT91C_TWR_12                   ((unsigned int) 0xC <<  8) // (SDDRC) Value : 12
#define 	AT91C_TWR_13                   ((unsigned int) 0xD <<  8) // (SDDRC) Value : 13
#define 	AT91C_TWR_14                   ((unsigned int) 0xE <<  8) // (SDDRC) Value : 14
#define 	AT91C_TWR_15                   ((unsigned int) 0xF <<  8) // (SDDRC) Value : 15
#define AT91C_TRC             ((unsigned int) 0xF << 12) // (SDDRC) 
#define 	AT91C_TRC_0                    ((unsigned int) 0x0 << 12) // (SDDRC) Value :  0
#define 	AT91C_TRC_1                    ((unsigned int) 0x1 << 12) // (SDDRC) Value :  1
#define 	AT91C_TRC_2                    ((unsigned int) 0x2 << 12) // (SDDRC) Value :  2
#define 	AT91C_TRC_3                    ((unsigned int) 0x3 << 12) // (SDDRC) Value :  3
#define 	AT91C_TRC_4                    ((unsigned int) 0x4 << 12) // (SDDRC) Value :  4
#define 	AT91C_TRC_5                    ((unsigned int) 0x5 << 12) // (SDDRC) Value :  5
#define 	AT91C_TRC_6                    ((unsigned int) 0x6 << 12) // (SDDRC) Value :  6
#define 	AT91C_TRC_7                    ((unsigned int) 0x7 << 12) // (SDDRC) Value :  7
#define 	AT91C_TRC_8                    ((unsigned int) 0x8 << 12) // (SDDRC) Value :  8
#define 	AT91C_TRC_9                    ((unsigned int) 0x9 << 12) // (SDDRC) Value :  9
#define 	AT91C_TRC_10                   ((unsigned int) 0xA << 12) // (SDDRC) Value : 10
#define 	AT91C_TRC_11                   ((unsigned int) 0xB << 12) // (SDDRC) Value : 11
#define 	AT91C_TRC_12                   ((unsigned int) 0xC << 12) // (SDDRC) Value : 12
#define 	AT91C_TRC_13                   ((unsigned int) 0xD << 12) // (SDDRC) Value : 13
#define 	AT91C_TRC_14                   ((unsigned int) 0xE << 12) // (SDDRC) Value : 14
#define 	AT91C_TRC_15                   ((unsigned int) 0xF << 12) // (SDDRC) Value : 15
#define AT91C_TRP             ((unsigned int) 0xF << 16) // (SDDRC) 
#define 	AT91C_TRP_0                    ((unsigned int) 0x0 << 16) // (SDDRC) Value :  0
#define 	AT91C_TRP_1                    ((unsigned int) 0x1 << 16) // (SDDRC) Value :  1
#define 	AT91C_TRP_2                    ((unsigned int) 0x2 << 16) // (SDDRC) Value :  2
#define 	AT91C_TRP_3                    ((unsigned int) 0x3 << 16) // (SDDRC) Value :  3
#define 	AT91C_TRP_4                    ((unsigned int) 0x4 << 16) // (SDDRC) Value :  4
#define 	AT91C_TRP_5                    ((unsigned int) 0x5 << 16) // (SDDRC) Value :  5
#define 	AT91C_TRP_6                    ((unsigned int) 0x6 << 16) // (SDDRC) Value :  6
#define 	AT91C_TRP_7                    ((unsigned int) 0x7 << 16) // (SDDRC) Value :  7
#define 	AT91C_TRP_8                    ((unsigned int) 0x8 << 16) // (SDDRC) Value :  8
#define 	AT91C_TRP_9                    ((unsigned int) 0x9 << 16) // (SDDRC) Value :  9
#define 	AT91C_TRP_10                   ((unsigned int) 0xA << 16) // (SDDRC) Value : 10
#define 	AT91C_TRP_11                   ((unsigned int) 0xB << 16) // (SDDRC) Value : 11
#define 	AT91C_TRP_12                   ((unsigned int) 0xC << 16) // (SDDRC) Value : 12
#define 	AT91C_TRP_13                   ((unsigned int) 0xD << 16) // (SDDRC) Value : 13
#define 	AT91C_TRP_14                   ((unsigned int) 0xE << 16) // (SDDRC) Value : 14
#define 	AT91C_TRP_15                   ((unsigned int) 0xF << 16) // (SDDRC) Value : 15
#define AT91C_TRRD            ((unsigned int) 0xF << 20) // (SDDRC) 
#define 	AT91C_TRRD_0                    ((unsigned int) 0x0 << 20) // (SDDRC) Value :  0
#define 	AT91C_TRRD_1                    ((unsigned int) 0x1 << 20) // (SDDRC) Value :  1
#define 	AT91C_TRRD_2                    ((unsigned int) 0x2 << 20) // (SDDRC) Value :  2
#define 	AT91C_TRRD_3                    ((unsigned int) 0x3 << 20) // (SDDRC) Value :  3
#define 	AT91C_TRRD_4                    ((unsigned int) 0x4 << 20) // (SDDRC) Value :  4
#define 	AT91C_TRRD_5                    ((unsigned int) 0x5 << 20) // (SDDRC) Value :  5
#define 	AT91C_TRRD_6                    ((unsigned int) 0x6 << 20) // (SDDRC) Value :  6
#define 	AT91C_TRRD_7                    ((unsigned int) 0x7 << 20) // (SDDRC) Value :  7
#define 	AT91C_TRRD_8                    ((unsigned int) 0x8 << 20) // (SDDRC) Value :  8
#define 	AT91C_TRRD_9                    ((unsigned int) 0x9 << 20) // (SDDRC) Value :  9
#define 	AT91C_TRRD_10                   ((unsigned int) 0xA << 20) // (SDDRC) Value : 10
#define 	AT91C_TRRD_11                   ((unsigned int) 0xB << 20) // (SDDRC) Value : 11
#define 	AT91C_TRRD_12                   ((unsigned int) 0xC << 20) // (SDDRC) Value : 12
#define 	AT91C_TRRD_13                   ((unsigned int) 0xD << 20) // (SDDRC) Value : 13
#define 	AT91C_TRRD_14                   ((unsigned int) 0xE << 20) // (SDDRC) Value : 14
#define 	AT91C_TRRD_15                   ((unsigned int) 0xF << 20) // (SDDRC) Value : 15
#define AT91C_TWTR            ((unsigned int) 0x1 << 24) // (SDDRC) 
#define 	AT91C_TWTR_0                    ((unsigned int) 0x0 << 24) // (SDDRC) Value :  0
#define 	AT91C_TWTR_1                    ((unsigned int) 0x1 << 24) // (SDDRC) Value :  1
#define AT91C_TMRD            ((unsigned int) 0xF << 28) // (SDDRC) 
#define 	AT91C_TMRD_0                    ((unsigned int) 0x0 << 28) // (SDDRC) Value :  0
#define 	AT91C_TMRD_1                    ((unsigned int) 0x1 << 28) // (SDDRC) Value :  1
#define 	AT91C_TMRD_2                    ((unsigned int) 0x2 << 28) // (SDDRC) Value :  2
#define 	AT91C_TMRD_3                    ((unsigned int) 0x3 << 28) // (SDDRC) Value :  3
#define 	AT91C_TMRD_4                    ((unsigned int) 0x4 << 28) // (SDDRC) Value :  4
#define 	AT91C_TMRD_5                    ((unsigned int) 0x5 << 28) // (SDDRC) Value :  5
#define 	AT91C_TMRD_6                    ((unsigned int) 0x6 << 28) // (SDDRC) Value :  6
#define 	AT91C_TMRD_7                    ((unsigned int) 0x7 << 28) // (SDDRC) Value :  7
#define 	AT91C_TMRD_8                    ((unsigned int) 0x8 << 28) // (SDDRC) Value :  8
#define 	AT91C_TMRD_9                    ((unsigned int) 0x9 << 28) // (SDDRC) Value :  9
#define 	AT91C_TMRD_10                   ((unsigned int) 0xA << 28) // (SDDRC) Value : 10
#define 	AT91C_TMRD_11                   ((unsigned int) 0xB << 28) // (SDDRC) Value : 11
#define 	AT91C_TMRD_12                   ((unsigned int) 0xC << 28) // (SDDRC) Value : 12
#define 	AT91C_TMRD_13                   ((unsigned int) 0xD << 28) // (SDDRC) Value : 13
#define 	AT91C_TMRD_14                   ((unsigned int) 0xE << 28) // (SDDRC) Value : 14
#define 	AT91C_TMRD_15                   ((unsigned int) 0xF << 28) // (SDDRC) Value : 15
// -------- SDDRC_T1PR : (SDDRC Offset: 0x10)  -------- 
#define AT91C_TRFC            ((unsigned int) 0x1F <<  0) // (SDDRC) 
#define 	AT91C_TRFC_0                    ((unsigned int) 0x0) // (SDDRC) Value :  0
#define 	AT91C_TRFC_1                    ((unsigned int) 0x1) // (SDDRC) Value :  1
#define 	AT91C_TRFC_2                    ((unsigned int) 0x2) // (SDDRC) Value :  2
#define 	AT91C_TRFC_3                    ((unsigned int) 0x3) // (SDDRC) Value :  3
#define 	AT91C_TRFC_4                    ((unsigned int) 0x4) // (SDDRC) Value :  4
#define 	AT91C_TRFC_5                    ((unsigned int) 0x5) // (SDDRC) Value :  5
#define 	AT91C_TRFC_6                    ((unsigned int) 0x6) // (SDDRC) Value :  6
#define 	AT91C_TRFC_7                    ((unsigned int) 0x7) // (SDDRC) Value :  7
#define 	AT91C_TRFC_8                    ((unsigned int) 0x8) // (SDDRC) Value :  8
#define 	AT91C_TRFC_9                    ((unsigned int) 0x9) // (SDDRC) Value :  9
#define 	AT91C_TRFC_10                   ((unsigned int) 0xA) // (SDDRC) Value : 10
#define 	AT91C_TRFC_11                   ((unsigned int) 0xB) // (SDDRC) Value : 11
#define 	AT91C_TRFC_12                   ((unsigned int) 0xC) // (SDDRC) Value : 12
#define 	AT91C_TRFC_13                   ((unsigned int) 0xD) // (SDDRC) Value : 13
#define 	AT91C_TRFC_14                   ((unsigned int) 0xE) // (SDDRC) Value : 14
#define 	AT91C_TRFC_15                   ((unsigned int) 0xF) // (SDDRC) Value : 15
#define AT91C_TXSNR           ((unsigned int) 0xFF <<  8) // (SDDRC) 
#define 	AT91C_TXSNR_0                    ((unsigned int) 0x0 <<  8) // (SDDRC) Value :  0
#define 	AT91C_TXSNR_1                    ((unsigned int) 0x1 <<  8) // (SDDRC) Value :  1
#define 	AT91C_TXSNR_2                    ((unsigned int) 0x2 <<  8) // (SDDRC) Value :  2
#define 	AT91C_TXSNR_3                    ((unsigned int) 0x3 <<  8) // (SDDRC) Value :  3
#define 	AT91C_TXSNR_4                    ((unsigned int) 0x4 <<  8) // (SDDRC) Value :  4
#define 	AT91C_TXSNR_5                    ((unsigned int) 0x5 <<  8) // (SDDRC) Value :  5
#define 	AT91C_TXSNR_6                    ((unsigned int) 0x6 <<  8) // (SDDRC) Value :  6
#define 	AT91C_TXSNR_7                    ((unsigned int) 0x7 <<  8) // (SDDRC) Value :  7
#define 	AT91C_TXSNR_8                    ((unsigned int) 0x8 <<  8) // (SDDRC) Value :  8
#define 	AT91C_TXSNR_9                    ((unsigned int) 0x9 <<  8) // (SDDRC) Value :  9
#define 	AT91C_TXSNR_10                   ((unsigned int) 0xA <<  8) // (SDDRC) Value : 10
#define 	AT91C_TXSNR_11                   ((unsigned int) 0xB <<  8) // (SDDRC) Value : 11
#define 	AT91C_TXSNR_12                   ((unsigned int) 0xC <<  8) // (SDDRC) Value : 12
#define 	AT91C_TXSNR_13                   ((unsigned int) 0xD <<  8) // (SDDRC) Value : 13
#define 	AT91C_TXSNR_14                   ((unsigned int) 0xE <<  8) // (SDDRC) Value : 14
#define 	AT91C_TXSNR_15                   ((unsigned int) 0xF <<  8) // (SDDRC) Value : 15
#define AT91C_TXSRD           ((unsigned int) 0xFF << 16) // (SDDRC) 
#define 	AT91C_TXSRD_0                    ((unsigned int) 0x0 << 16) // (SDDRC) Value :  0
#define 	AT91C_TXSRD_1                    ((unsigned int) 0x1 << 16) // (SDDRC) Value :  1
#define 	AT91C_TXSRD_2                    ((unsigned int) 0x2 << 16) // (SDDRC) Value :  2
#define 	AT91C_TXSRD_3                    ((unsigned int) 0x3 << 16) // (SDDRC) Value :  3
#define 	AT91C_TXSRD_4                    ((unsigned int) 0x4 << 16) // (SDDRC) Value :  4
#define 	AT91C_TXSRD_5                    ((unsigned int) 0x5 << 16) // (SDDRC) Value :  5
#define 	AT91C_TXSRD_6                    ((unsigned int) 0x6 << 16) // (SDDRC) Value :  6
#define 	AT91C_TXSRD_7                    ((unsigned int) 0x7 << 16) // (SDDRC) Value :  7
#define 	AT91C_TXSRD_8                    ((unsigned int) 0x8 << 16) // (SDDRC) Value :  8
#define 	AT91C_TXSRD_9                    ((unsigned int) 0x9 << 16) // (SDDRC) Value :  9
#define 	AT91C_TXSRD_10                   ((unsigned int) 0xA << 16) // (SDDRC) Value : 10
#define 	AT91C_TXSRD_11                   ((unsigned int) 0xB << 16) // (SDDRC) Value : 11
#define 	AT91C_TXSRD_12                   ((unsigned int) 0xC << 16) // (SDDRC) Value : 12
#define 	AT91C_TXSRD_13                   ((unsigned int) 0xD << 16) // (SDDRC) Value : 13
#define 	AT91C_TXSRD_14                   ((unsigned int) 0xE << 16) // (SDDRC) Value : 14
#define 	AT91C_TXSRD_15                   ((unsigned int) 0xF << 16) // (SDDRC) Value : 15
// -------- SDDRC_HS : (SDDRC Offset: 0x14)  -------- 
#define AT91C_DA              ((unsigned int) 0x1 <<  0) // (SDDRC) 
#define AT91C_OVL             ((unsigned int) 0x1 <<  1) // (SDDRC) 
// -------- SDDRC_LPR : (SDDRC Offset: 0x18)  -------- 
#define AT91C_LPCB            ((unsigned int) 0x3 <<  0) // (SDDRC) 
#define AT91C_PASR            ((unsigned int) 0x7 <<  4) // (SDDRC) 
#define AT91C_LP_TRC          ((unsigned int) 0x3 <<  8) // (SDDRC) 
#define AT91C_DS              ((unsigned int) 0x3 << 10) // (SDDRC) 
#define AT91C_TIMEOUT         ((unsigned int) 0x3 << 12) // (SDDRC) 
// -------- SDDRC_MDR : (SDDRC Offset: 0x1c)  -------- 
#define AT91C_MD              ((unsigned int) 0x3 <<  0) // (SDDRC) 
#define 	AT91C_MD_SDR_SDRAM            ((unsigned int) 0x0) // (SDDRC) SDR_SDRAM
#define 	AT91C_MD_LP_SDR_SDRAM         ((unsigned int) 0x1) // (SDDRC) Low Power SDR_SDRAM
#define 	AT91C_MD_DDR_SDRAM            ((unsigned int) 0x2) // (SDDRC) DDR_SDRAM
#define 	AT91C_MD_LP_DDR_SDRAM         ((unsigned int) 0x3) // (SDDRC) Low Power DDR_SDRAM
#define AT91C_B16MODE         ((unsigned int) 0x1 <<  4) // (SDDRC) 
#define 	AT91C_B16MODE_32_BITS              ((unsigned int) 0x0 <<  4) // (SDDRC) 32 Bits datas bus
#define 	AT91C_B16MODE_16_BITS              ((unsigned int) 0x1 <<  4) // (SDDRC) 16 Bits datas bus


#endif ///SDRAM_H
//! @}