//-----------------------------------------------------------------------------
//! \addtogroup	MISC
//! @{
//!
//  All rights reserved ADENEO 2007
//!
//-----------------------------------------------------------------------------
//! \file		COMMON/INC/atmel_gpio_struct.h
//!
//! \brief		Structures and type definitions for GPIO library
//!
//! \if subversion
///   @URL: $URL: http://centaure/svn/interne-ce_bsp_atmel/TAGS/TAGS60/RC/SAM9263_v130_rc7/PLATFORM/COMMON/SRC/SOC/ATMEL/COMMON/INC/atmel_gpio_struct.h $
//!   @author $Author: pgal $
//!   @version $Revision: 1290 $
//!   @date $Date: 2007-08-10 16:59:42 +0200 (ven., 10 août 2007) $
//! \endif
//-----------------------------------------------------------------------------
//! \addtogroup	GPIO
//! @{

#ifndef __ATMEL_GPIO_STRUCT_H__
#define __ATMEL_GPIO_STRUCT_H__

//------------------------------------------------------------------------------
//                                                               Defines & Types
//------------------------------------------------------------------------------
#include "at91_pio.h"

/* I/O type */
enum  pio_type {
	PIO_PERIPH_A,
	PIO_PERIPH_B,
	PIO_INPUT,
	PIO_OUTPUT,
	PIO_UNDEFINED
};
/* I/O attributes */
#define PIO_DEFAULT   (0 << 0)
#define PIO_PULLUP    (1 << 0)
#define PIO_DEGLITCH  (1 << 1)
#define PIO_OPENDRAIN (1 << 2)

struct pio_desc {
	const char *pin_name;   /* Pin Name */
	unsigned int pin_num;   /* Pin number */
	unsigned int dft_value; /* Default value for outputs */
	unsigned char attribute;
	enum pio_type type;
};

typedef struct {
	AT91PS_PIO pBase;
	DWORD nbPin; //Not every PIO controller support the same number of pin.
	DWORD currentPin;//This is used to maintain a round robin priority system within the same PIO bank
	DWORD status; // this is use to maintain the value of PIO_ISR because it's cleared after each reading
	DWORD logintrBase; //This is the logintr associated with pin 0 of the bank
	DWORD deviceID; //this is to configure the AIC
	AT91PS_PIO vPioBase;
	DWORD resumeMask;
} T_PIO_BANK_DESCRIPTION;

#define END_OF_PIO {NULL, 0, 0, 0, PIO_UNDEFINED}

#define IS_GPIO		(0<<0)
#define IS_PERIPH_A	(1<<0)
#define IS_PERIPH_B	(2<<0)

#endif /* __ATMEL_GPIO_STRUCT_H__*/
//! @}
//! @}
