//-----------------------------------------------------------------------------
//! \addtogroup	I2C
//! @{
//!  
//  All rights reserved ADENEO SAS 2005
//!
//-----------------------------------------------------------------------------
//! \file		atmel_i2c.h
//!
//! \if subversion
//!   $URL: http://centaure/svn/interne-ce_bsp_atmel/TAGS/TAGS60/RC/SAM9263_v130_rc7/PLATFORM/COMMON/SRC/SOC/ATMEL/COMMON/INC/atmel_i2c.h $
//!   $Author: pblanchard $
//!   $Revision: 994 $
//!   $Date: 2007-06-13 15:51:25 +0200 (mer., 13 juin 2007) $
//! \endif
//!
//! Header for I2C driver
//-----------------------------------------------------------------------------

#ifndef __I2CDRIVER_H__
#define __I2CDRIVER_H__

#include "at91_twi.h"
#include "at91_pdc.h"
#include "at91_pmc.h"

// Structures
// Init context structure
typedef struct {
	AT91PS_TWI pTWIReg;				//!< virtual base address of I2C controller
	AT91PS_PDC pPDCReg;				//!< virtual base address of I2C controller's PDC (not used)
	AT91PS_PMC	pPMCReg;			//!< virtual base address of PMC
	CRITICAL_SECTION scI2CAccess;	//!< Critical section used to protect access to the I2C data and registers
	DWORD dwOpenCount;				//!< To keep track of how many time the instance has been opened
	DWORD dwShareMode;				//!< To keep track of the share mode of the instance. 
	DWORD dwDefaultTWIClkDiv;		//!< I2C Default Clock divider
	CEDEVICE_POWER_STATE CurrentDx;	//!< Driver current power state
} T_I2CINIT_STRUCTURE, *PT_I2CINIT_STRUCTURE;

// Open context structure
typedef struct {
	T_I2CINIT_STRUCTURE *pDeviceContext;	
	DWORD dwAccessCode;			//!< To keep track of the access mode (READ, WRITE or READ/WRITE)
	DWORD dwTWIClkDiv;				//!< Auctual I2C Clock divider
} T_I2COPEN_STRUCTURE, *PT_I2COPEN_STRUCTURE;


// Public interfaces
BOOL	WINAPI	I2C_DllEntry(HANDLE hinstDLL, DWORD dwReason, LPVOID  lpvReserved); 
DWORD	I2C_Init	(LPCTSTR pContext, LPCVOID lpvBusContext);
BOOL	I2C_Deinit	(T_I2CINIT_STRUCTURE *pDeviceContext);
DWORD	I2C_Open	(T_I2CINIT_STRUCTURE *pDeviceContext, DWORD AccessCode, DWORD ShareMode);
BOOL	I2C_Close	(T_I2COPEN_STRUCTURE *pOpenContext);
DWORD	I2C_Read	(T_I2COPEN_STRUCTURE *pOpenContext, LPVOID pBuffer, DWORD dwCount);
DWORD	I2C_Write	(T_I2COPEN_STRUCTURE *pOpenContext, LPCVOID pBuffer, DWORD dwCount);
DWORD	I2C_Seek	(T_I2COPEN_STRUCTURE *pOpenContext, long Amount, WORD wType);
BOOL	I2C_IOControl (T_I2COPEN_STRUCTURE *pOpenContext, DWORD dwCode, PBYTE pBufIn, DWORD dwLenIn, PBYTE pBufOut, DWORD dwLenOut, PDWORD pdwActualOut);
void	I2C_PowerDown (T_I2CINIT_STRUCTURE *pDeviceContext);
void	I2C_PowerUp	  (T_I2CINIT_STRUCTURE *pDeviceContext);

// Internal usage
BOOL LoadRegistry(LPCTSTR pContext, T_I2CINIT_STRUCTURE *pDeviceContext);
BOOL I2C_ReadData (T_I2COPEN_STRUCTURE *pOpenContext, DWORD dwDeviceAddr, DWORD dwRegAddress, IADDR_SIZE eAddressSize, BOOL bDisableInt, LPBYTE pBuffer, LPDWORD lpdwBufferSize);
BOOL I2C_WriteData (T_I2COPEN_STRUCTURE *pOpenContext, DWORD dwDeviceAddr, DWORD dwRegAddress, IADDR_SIZE eAddressSize, BOOL bDisableInt, LPBYTE pBuffer, LPDWORD lpdwBufferSize);
DWORD AT91F_ComputeTwiClock(DWORD dwTranfertRate);
void AT91F_SetTwiClock(AT91PS_TWI pTwi, DWORD dwClockDiv);

// Hardware Specific intialisation
extern BOOL ConfigurePioForI2C();


#endif // #define __I2CDRIVER_H__

// End of Doxygen group I2C Driver
//! @}
//-----------------------------------------------------------------------------
// End of $URL: http://centaure/svn/interne-ce_bsp_atmel/TAGS/TAGS60/RC/SAM9263_v130_rc7/PLATFORM/COMMON/SRC/SOC/ATMEL/COMMON/INC/atmel_i2c.h $
//-----------------------------------------------------------------------------
//
