//-----------------------------------------------------------------------------
//! \addtogroup OAL
//! @{
//!  
//  All rights reserved ADENEO SAS 2005
//!
//-----------------------------------------------------------------------------
//! \file		atmel_pll.h
//!
//! \if subversion
//!   $URL: http://centaure/svn/interne-ce_bsp_atmel/TAGS/TAGS60/RC/SAM9263_v130_rc7/PLATFORM/COMMON/SRC/SOC/ATMEL/COMMON/INC/atmel_pll.h $
//!   $Author: ovigliengo $
//!   $Revision: 1943 $
//!   $Date: 2008-06-02 18:25:45 +0200 (lun., 02 juin 2008) $
//! \endif
//!
//! TODO : comment the header/add to a group ?
//-----------------------------------------------------------------------------

#ifndef PLL_H
#define PLL_H

// controllers includes
#include "at91_pmc.h"
#include "at91_dbgu.h"
///////////////////////////////////////////// PLL ////////////////////////////////////////////////////////

//-----------------------------------------------------------------------------
//! \fn		DWORD GetMasterClock(BOOL bUseShadowedValue)
//!
//! \brief		This function is called by the kernel to retreive the value of the Master clock in Hz
//!
//!	\param		bUseShadowedValue	(BOOL) TRUE to use shadowed value
//!
//! \return		value of Master clock in Hz
//!
//! 
//-----------------------------------------------------------------------------
DWORD GetMasterClock(BOOL bUseShadowedValue);

//-----------------------------------------------------------------------------
//! \fn		DWORD GetPLLAClock(BOOL bUseShadowedValue)
//!
//! \brief		This function is called by the kernel to retreive the value of the PLLA clock in Hz
//!
//!	\param		bUseShadowedValue	(BOOL) TRUE to use shadowed value
//!
//! \return		value of PLLA clock in Hz
//!
//! 
//-----------------------------------------------------------------------------
DWORD GetPLLAClock(BOOL bUseShadowedValue);

//-----------------------------------------------------------------------------
//! \fn		DWORD GetPLLBClock(BOOL bUseShadowedValue)
//!
//! \brief		This function is called by the kernel to retreive the value of the PLLB clock in Hz
//!
//!	\param		bUseShadowedValue	(BOOL) TRUE to use shadowed value
//!
//! \return		value of PLLB clock in Hz
//!
//! 
//-----------------------------------------------------------------------------
DWORD GetPLLBClock(BOOL bUseShadowedValue);

//-----------------------------------------------------------------------------
//! \fn		DWORD GetProcessorClock(BOOL bUseShadowedValue)
//!
//! \brief		This function is called by the kernel to retreive the value of the Processor clock in Hz
//!
//!	\param		bUseShadowedValue	(BOOL) TRUE to use shadowed value
//!
//! \return		value of Processor clock in Hz
//!
//! 
//-----------------------------------------------------------------------------
DWORD GetProcessorClock(BOOL bUseShadowedValue);



//------------------------------------------------------------------------------
//
//  Function:     GetMainClock
//
//  This function is called by the kernel to retreive the value of the main clock in Hz
//
DWORD GetMainClock(BOOL bUseShadowedValue);

//-----------------------------------------------------------------------------
//! \fn		void TurnProcessorClockOff()
//!
//! \brief		This function is called by the kernel to stop the processor clock and thus enter the idle/suspend mode.
//!
//-----------------------------------------------------------------------------
void TurnProcessorClockOff();

//-----------------------------------------------------------------------------
//! \fn		DWORD SetPLLBFreq(AT91PS_PMC pPMC,DWORD dwFreqInMHz, DWORD dwUSBDivider)
//!
//! \brief		This function is called by the kernel to set the PLLB frequency
//!
//-----------------------------------------------------------------------------
DWORD SetPLLBFreq(AT91PS_PMC pPMC,DWORD dwFreqInMHz, DWORD dwUSBDivider);


//-----------------------------------------------------------------------------
//! \fn		BOOL SetProcessorAndMasterClocks(AT91PS_PMC pPMC, DWORD dwProcessorClockInMHz, DWORD dwBusClockRatio)
//!
//! \brief		This function is called by the kernel to set the value of the clocks in Hz
//!
//-----------------------------------------------------------------------------
BOOL SetProcessorAndMasterClocks(	AT91PS_PMC pPMC				,
												DWORD dwProcessorClockInMHz	,
												DWORD dwBusClockRatio		);
												
////////////////////////////////////////// Serial //////////////////////////////////////////////////////
//------------------------------------------------------------------------------
//
//  Variable:     g_pDBGU
//
//  This variable is used by the AT91RM9200 API to know the base address of the DBGU controller.
// It must be initialized before the initialization code is used. otherwise the default value for the processor is used instead
//
extern AT91PS_DBGU g_pDBGU;
//------------------------------------------------------------------------------
//
//  Function:     SetDebugSerialInterface
//
//  This function is called to set the value of g_pDBGU in a proper way
//

void SetDebugSerialInterface(AT91PS_DBGU pDBGU);

#endif /// PLL_H
//! @}
